==> qlcplus_4.12.4.orig.tar.xz: qlcplus-QLC-_4.12.4/plugins/gpio/GPIO_fr_FR.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="fr_FR">
<context>
    <name>GPIOConfiguration</name>
    <message>
        <location filename="gpioconfiguration.ui" line="14"/>
        <source>Configure GPIO Plugin</source>
        <translation>Configuration du plugin GPIO</translation>
    </message>
    <message>
        <location filename="gpioconfiguration.ui" line="28"/>
        <source>GPIO Number</source>
        <translation>Numéro de GPIO</translation>
    </message>
    <message>
        <location filename="gpioconfiguration.ui" line="33"/>
        <source>Usage</source>
        <translation>Utilisation</translation>
    </message>
    <message>
        <location filename="gpioconfiguration.cpp" line="57"/>
        <source>Not used</source>
        <translation>Non utilisée</translation>
    </message>
    <message>
        <location filename="gpioconfiguration.cpp" line="58"/>
        <source>Input</source>
        <translation>Entrée</translation>
    </message>
    <message>
        <location filename="gpioconfiguration.cpp" line="59"/>
        <source>Output</source>
        <translation>Sortie</translation>
    </message>
</context>
<context>
    <name>GPIOPlugin</name>
    <message>
        <location filename="gpioplugin.cpp" line="84"/>
        <source>This plugin provides input/output on GPIO PINs.</source>
        <translation>Ce plugin offre le support des entrées/sorties sur pins GPIO.</translation>
    </message>
</context>
</TS>

==> qlcplus_4.14.1.orig.tar.xz: qlcplus-QLC-_4.14.1/plugins/gpio/GPIO_fr_FR.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr_FR">
<context>
    <name>GPIOConfiguration</name>
    <message>
        <location filename="gpioconfiguration.ui" line="33"/>
        <source>Configure GPIO Plugin</source>
        <translation>Configuration du plugin GPIO</translation>
    </message>
    <message>
        <location filename="gpioconfiguration.ui" line="46"/>
        <source>Selected chip</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="gpioconfiguration.ui" line="57"/>
        <source>GPIO Number</source>
        <translation>Numéro de GPIO</translation>
    </message>
    <message>
        <location filename="gpioconfiguration.ui" line="62"/>
        <source>Usage</source>
        <translation>Utilisation</translation>
    </message>
    <message>
        <location filename="gpioconfiguration.ui" line="67"/>
        <source>Channel number</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="gpioconfiguration.cpp" line="79"/>
        <source>Not used</source>
        <translation>Non utilisée</translation>
    </message>
    <message>
        <location filename="gpioconfiguration.cpp" line="80"/>
        <source>Input</source>
        <translation>Entrée</translation>
    </message>
    <message>
        <location filename="gpioconfiguration.cpp" line="81"/>
        <source>Output</source>
        <translation>Sortie</translation>
    </message>
</context>
<context>
    <name>GPIOPlugin</name>
    <message>
        <location filename="gpioplugin.cpp" line="97"/>
        <source>This plugin provides input/output on GPIO PINs.</source>
        <translation>Ce plugin offre le support des entrées/sorties sur pins GPIO.</translation>
    </message>
</context>
</TS>
